function  Contour_Plotter(figno, phi, x, Radius, linewidth, fontsize, Contour_levels, colors, alpha)
% The contour plotter plots contours of equivalence ratios.
%   Inputs are (1)figure number
%              (2)equivalence ratio
%              (3)the axial coordinates of the CVs
%              (4)the radii of the CVs
%              (5)the desired linewidth
%              (6)the desired font size
%              (7)the desired contour levels
%              (8)the desired contour colors
%              (9)the alpha array of the profile factors
%
%   Output: A contour plot is output to the screen, and will be written
%           over with each function run.

w = 0;
gamma = (alpha+1).*(alpha+2)./alpha.^2;
for EQ = Contour_levels
   w=w+1;
	ii = find(gamma.*phi > EQ );
	break_point = find(ii(2:end)-ii(1:end-1)~=1); %the index given is the last index to go into the particular cell column
	break_point(end+1) = length(ii); %without this the last set of ii indexes are not used 
	zeta = ( 1 - sqrt(EQ./phi(ii)./gamma(ii)) ).^(1./alpha(ii));
   y_radial =[zeta .* Radius(ii)]; % zero added to align y_radial with the corresponding CV
   
   i = 1; % x counter
   for k = 1:length(break_point)
		Contour{w,k} = [ x(ii(i:break_point(k))) ; y_radial(i:break_point(k)) ];
		if k < length(break_point)
			i = break_point(k)+1;   %prevents from seeking a k value that is one past the end
      end
	end
	levels(w) = length(break_point);  % matrix to keep track of the number of distinct patches of equal EQ ratio for each EQ ratio
end

c = 1; %color index
for w = 1:size(Contour,1)
	for k = 1:levels(w)
      if length(Contour{w,k}(1,:)) > 0
         
         if (w==1 | w==11)
            bold=1;
         else
            bold=0;
         end
         
%         patch( [Contour{w,k}(1,:)  Contour{w,k}(1,end:-1:1) Contour{w,k}(1,1)]*1000 , ...
%               [Contour{w,k}(2,:) -Contour{w,k}(2,end:-1:1) Contour{w,k}(2,1)]*1000 , ...
%               w/length(Contour_levels)*[1 1 1]) % times 1000 to get into mm
%            if sum(Contour_levels(w)==[1 10])
               plot ( [Contour{w,k}(1,:)  Contour{w,k}(1,end:-1:1) Contour{w,k}(1,1)]*1000 , ...
               	[Contour{w,k}(2,:) -Contour{w,k}(2,end:-1:1) Contour{w,k}(2,1)]*1000 , ...
            		'-','Color',colors{c},'LineWidth',linewidth+bold) % times 1000 to get into mm
%				end
		%else
      %   plot( [Contour{i,k}(1,:)*1000 Contour{i,k}(1,end:-1:1)*1000  ] , ...
      %      [ Contour{i,k}(2,:)*1000 -Contour{i,k}(2,end:-1:1)*1000  ] , ...
      %      colors(u),'LineWidth',linewidth) % times 1000 to get into mm
		end
		hold on 
	end
   
   c=c+1;
	if c > length(colors)
		c = 1;
	end
end

return    
    
    