function [time,x,Xf_doublebar] = Kattke_Penetration_Steady( rho_fuel , rho_air , m , theta , x , x_sub0 , U0, d_subf , Beta)
% Returns relationship between penetration and time using Naber and Siebers
% equations.
%   Inputs are (1) Density of fuel
%              (2) Density of charge
%              (3)  m - equation variable that either neglects the area of
%                      fuel(set to 0) or includes the area of fuel(set to 1)
%              (4) The angle of the full spray used in the model.  This is
%                  the measured spray angle in degrees 
%                  where theta is the angle measured by experiment.  
%              (5) The axial distance where time to penetration is desired.
%              (6) The axial distance from edge of injector to theoretical
%                  location of point injection.
%              (7) The injector velocity.
%              (8) The effective orifice diameter in meters of the
%                  injector.
%              (9) Beta

%   Output:     (1) Matrix containing corresponding penetration time
%               (2) and matrix containing distance 
%               (3) Cross-sectional average (double bar) liquid volume fraction


rho_tilda = rho_fuel / rho_air; 
x_suba = m/2 * d_subf/tand(theta/2);
x_prime = x + x_sub0;
x_plus = d_subf * rho_tilda^0.5 * ((rho_tilda - m)/rho_tilda) * 1/tand(theta/2);
t_plus = d_subf * rho_tilda^0.5 * ((rho_tilda-m)/rho_tilda)^2 * 1/(U0*tand(theta/2));
S_tilda = x_prime ./ x_plus;         
         
t_tilda = S_tilda./2/Beta + S_tilda./4/Beta .* sqrt(1 + 16*Beta.* S_tilda.^2) + 1/16/Beta^1.5 .* log(4*Beta .* S_tilda + sqrt(1 + 16*Beta .* S_tilda.^2));

t_sub0 = t_tilda(1,1) * t_plus;
t_prime = t_tilda .* t_plus;
time = t_prime - t_sub0 ;
%Eq 12 from 2010-01-0686
Xf_doublebar = 2./( (rho_tilda-1)*(sqrt(1 + 16*Beta.* S_tilda.^2) -1) );

%CHECK this: FA = 2./( (1-1/rho_tilda)*sqrt(1 + 16*Beta.* S_tilda.^2) -1 -1/rho_tilda);
