% Musculus Kattke model for penetration and mixing at Spray A conditions
rho_f = 699;
rho_a = 22.8;
Ca = 0.95;
Cd = 0.86;
d = 0.090e-3; %nominal diamter
D_f = sqrt(Ca)*d; %effective diameter
theta = 21.5; %full angle degrees 
DP = 1500-60; %fuel injection pressure difference, bar
x = 0:0.001:0.1;
x0=D_f/2/tand(theta/2); %virtual origin
R = tand(theta/2)*(x+x0); %jet radius
U0 = Cd/Ca*sqrt(2*(DP)*1e5/rho_f); %injection velocity
alpha = 1.5;
gamma = (alpha+1)*(alpha+2)/alpha^2;
beta = 6*(alpha+1)*(alpha+2) / (3*alpha +2) / (2*alpha+1);
[time,S,Xfsteady] = Kattke_Penetration_Steady(rho_f,rho_a,1,theta,x,x0,U0,D_f,beta);
%plot mixing at certain axial distance
axd = 25; %axial distance mm
a = find(x*1000>=axd); ind = a(1);

xi = 0:0.01:1; %dimensionless radial coordinate
r = xi*R(ind); %radius [m]
Xfrad = Xfsteady(ind).*gamma.*(1-xi.^alpha).^2;
FArad = rho_f*Xfrad./(rho_a.*(1-Xfrad));
Zmodrad = FArad./(FArad + 1);
 figure(3), plot(r*1e3,Zmodrad,'r-',-r*1e3,Zmodrad,'r-');
 ylabel('mixture fraction'); xlabel('radial distance [mm]');
 dlmwrite('x25.txt',[r' Zmodrad'])
 %plot penetration
 figure(4), plot(time*1e6,S*1000);
 ylabel('Jet penetration'); xlabel('Time ASI [\mus]');
  dlmwrite('Pen.txt',[time' S'])